/**
 * ========================================
 * <libname> : a free Java <foobar> library
 * ========================================
 *
 * Project Info:  http://www.jfree.org/liblayout/
 * Project Lead:  Thomas Morgner;
 *
 * (C) Copyright 2005, by Object Refinery Limited and Contributors.
 *
 * This library is free software; you can redistribute it and/or modify it under the terms
 * of the GNU Lesser General Public License as published by the Free Software Foundation;
 * either version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License along with this
 * library; if not, write to the Free Software Foundation, Inc., 59 Temple Place, Suite 330,
 * Boston, MA 02111-1307, USA.
 *
 * ---------
 * JakartaLogTarget.java
 * ---------
 *
 * Original Author:  Thomas Morgner;
 * Contributors: -;
 *
 * $Id: JakartaLogTarget.java,v 1.1 2006/03/23 19:39:57 taqua Exp $
 *
 * Changes
 * -------------------------
 * 23.03.2006 : Initial version
 */
package org.jfree.logger.jcl;

import org.jfree.util.LogTarget;
import org.jfree.JCommon;
import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

/**
 * Creation-Date: 23.03.2006, 19:26:00
 *
 * @author Thomas Morgner
 */
public class JakartaLogTarget implements LogTarget
{
  private Log logger;

  public JakartaLogTarget ()
  {
    logger = LogFactory.getLog(JCommon.class);
  }

  /**
   * Logs a message to the main log stream.  All attached log targets will also receive
   * this message. If the given log-level is higher than the given debug-level in the main
   * config file, no logging will be done.
   *
   * @param level   log level of the message.
   * @param message text to be logged.
   */
  public void log (final int level, final Object message)
  {
    if (level == LogTarget.DEBUG)
    {
      logger.debug(message);
    }
    else if (level == LogTarget.INFO)
    {
      logger.info(message);
    }
    else if (level == LogTarget.WARN)
    {
      logger.warn(message);
    }
    else if (level == LogTarget.ERROR)
    {
      logger.error(message);
    }
    else
    {
      logger.fatal(message);
    }
  }

  /**
   * Logs a message to the main log stream. All attached logTargets will also receive this
   * message. If the given log-level is higher than the given debug-level in the main
   * config file, no logging will be done.
   * <p/>
   * The exception's stacktrace will be appended to the log-stream
   *
   * @param level   log level of the message.
   * @param message text to be logged.
   * @param e       the exception, which should be logged.
   */
  public void log (final int level, final Object message, final Exception e)
  {
    if (level == LogTarget.DEBUG)
    {
      logger.debug(message, e);
    }
    else if (level == LogTarget.INFO)
    {
      logger.info(message, e);
    }
    else if (level == LogTarget.WARN)
    {
      logger.warn(message, e);
    }
    else if (level == LogTarget.ERROR)
    {
      logger.error(message, e);
    }
    else
    {
      logger.fatal(message, e);
    }
  }
}
